@@ -9,7 +9,7 @@ from string import Template
 class LabExt(Module):
     """Module that provides basic functions and containers to widget wrappers in the `labext.widgets` packages.
     """
-
+    version = "1.0"
     container = "LabExtContainer1292931"
     call_until_true = "__CallUntilReturnTrue_BV12__"
 
@@ -23,7 +23,7 @@ class LabExt(Module):
 
     @classmethod
     def js(cls) -> Dict[str, str]:
-        return {}
+        return {cls.id(): f"/custom/labext/{cls.id()}/js/misc_func.{cls.version}"}
 
     @classmethod
     def dependencies(cls) -> List[Type['Module']]:
@@ -31,7 +31,11 @@ class LabExt(Module):
 
     @classmethod
     def register(cls, use_local: bool = True, suppress_display: bool = False):
-        jscode = Template("""
+        infile = cls.get_local_dir() / "js" / f"misc_func.{cls.version}.js"
+        if not infile.exists():
+            infile.parent.mkdir(exist_ok=True, parents=True)
+            with open(str(infile), "w") as f:
+                jscode = Template("""
 // create a container so that widget wrappers can use to store some information
 if (window.$container === undefined) {
     window.$container = {};
@@ -48,11 +52,9 @@ if (window.$CallUntilTrue === undefined) {
     }
     window.$CallUntilTrue = $CallUntilTrue
 }
-        """.strip()).substitute(
-            container=cls.container,
-            CallUntilTrue=cls.call_until_true)
+                        """.strip()).substitute(
+                    container=cls.container,
+                    CallUntilTrue=cls.call_until_true)
+                f.write(jscode)
 
-        if not suppress_display:
-            display(Javascript(jscode))
-        Module.registered_modules[cls.id()] = True
-        return jscode
\ No newline at end of file
+        return super().register(use_local, suppress_display)
