@@ -42,21 +42,22 @@ class Tippy(Module):
     @classmethod
     def register(cls, use_local: bool = True, suppress_display: bool = False):
         result = super().register(use_local, suppress_display)
-        display(cls.tunnel, Javascript(Template("""
-require(["@popperjs/core", "tippy"], function (popper, tippy) {
-    $CallUntilTrue(function () {
-        if (window.IPyCallback === undefined || window.IPyCallback.get("$tunnelId") === undefined) {
-            return false;
-        }
-
-        window.IPyCallback.get("$tunnelId").on_receive((version, payload) => {
-            let msg = JSON.parse(payload);
-            tippy(`$${msg.selector} [data-tippy-content]`, msg.params);
-        });
-        return true;
-    }, 100);
-});        
-        """).substitute(tunnelId=cls.tunnel.tunnel_id, CallUntilTrue=LabExt.call_until_true)))
+        # jscode = Javascript(Template("""
+        # require(["@popperjs/core", "tippy"], function (popper, tippy) {
+        #     $CallUntilTrue(function () {
+        #         if (window.IPyCallback === undefined || window.IPyCallback.get("$tunnelId") === undefined) {
+        #             return false;
+        #         }
+        #
+        #         window.IPyCallback.get("$tunnelId").on_receive((version, payload) => {
+        #             let msg = JSON.parse(payload);
+        #             tippy(`$${msg.selector} [data-tippy-content]`, msg.params);
+        #         });
+        #         return true;
+        #     }, 100);
+        # });
+        #         """).substitute(tunnelId=cls.tunnel.tunnel_id, CallUntilTrue=LabExt.call_until_true))
+        # display(cls.tunnel, jscode)
         return result
 
     @classmethod
